@@ -29,30 +29,6 @@
 
 $gCms = cmsms(); if( !is_object($gCms) ) exit;
 
-$detailpage = '';
-if (isset($params['detailpage']))
-  {
-    $manager =& $gCms->GetHierarchyManager();
-    $node =& $manager->sureGetNodeByAlias($params['detailpage']);
-    if (isset($node))
-      {
-	$content =& $node->GetContent();
-	if (isset($content))
-	  {
-	    $detailpage = $content->Id();
-	  }
-      }
-    else
-      {
-	$node =& $manager->sureGetNodeById($params['detailpage']);
-	if (isset($node))
-	  {
-	    $detailpage = $params['detailpage'];
-	  }
-      }
-  }
-
-
 if (!$this->CheckPermission('Use ServiceDesk'))
 {
 	echo $this->ShowErrors($this->Lang('needpermission', array('Use ServiceDesk')));
@@ -70,6 +46,8 @@ if (FALSE == empty($params['detail_tab']))
 } else {
 	$tab = '';
 }
+$servicedeskversion = $this->GetPreference('servicedeskversion');
+$config =& $gCms->GetConfig();
 
 echo $this->StartTabHeaders();
 	echo $this->SetTabHeader('incidentdetail',$this->Lang('title_incidentdetail'), ('incidentdetail' == $tab)?true:false);
@@ -215,7 +193,107 @@ echo $this->StartTabContent();
 					$this->CloseIncident($incident_id);
 				}
 			}
-			
+
+			if ($servicedeskversion == 'gold') {
+				// Insert the attributes for this incident
+				// First remove the existing attributes of the incident
+				$query = 'DELETE FROM '.cms_db_prefix().'module_servicedesk_incident_attributes 
+				WHERE incident_id = ?';
+				$db->Execute($query, array((int)$params['incident_id']));
+				// Use only filled fields
+				foreach ( $params as $key => $value ) {
+					if( !preg_match('/fld_/', $key ) )
+					{
+						continue;
+					}
+					$value = trim($value);
+					
+					// Adjust the key to get the field name
+					$fldname = substr($key,4);
+					if( !isset($params['info_'.$fldname]) )
+					{
+						// Something went wrong, trigger error
+						continue;
+					}
+					list($fldtype,$fldid) = explode(',',trim($params['info_'.$fldname]));
+					$pass = true;
+					switch( $fldtype )
+					{
+					case 'image':
+						{
+							$res = true;
+							if( isset( $params['del_'.$fldname] ) ) {
+								$res = sdattr_utils::IncidentImageDelete($id, $incident_id, $value);
+								// Now that image has been deleted, bail out otherwise image will be loaded again
+								$value = '';
+								break;
+							}
+							if( !$res )	{
+								$pass = false;
+								$errors[] = $this->Lang('error_filedelete');
+							}
+							else {
+								$t_value = '';
+								$t_result = '';
+								$res = sdattr_utils::IncidentImageUpload($id, $key, $incident_id,
+									$t_value,$t_result);
+								if( !$res && !empty($result))
+								{
+									$pass = false;
+									$errors[] = $t_result;
+								}
+								if( $res && !empty($t_value) )
+								{
+									$value = $t_value;
+								}
+							}
+						}
+						break;
+						
+					case 'file':
+						{
+							$res = true;
+							if( isset( $params['del_'.$fldname] ) ) {
+								$res = sdattr_utils::IncidentFileDelete($id, $incident_id, $value);
+								// Now that file has been deleted, bail out otherwise file will be loaded again
+								$value = '';
+								break;
+							}
+							
+							if( !$res ) {
+								$pass = false;
+								$errors[] = $this->Lang('error_filedelete');
+							}
+							else {
+								$t_value = '';
+								$t_result = '';
+								$res = sdattr_utils::IncidentFileUpload($id, $key, $incident_id,
+									$value,$result);
+								if( !$res && !empty($result))
+								{
+									$pass = false;
+									$errors[] = $result;
+								}
+								if( $res && !empty($t_value) )
+								{
+									$value = $t_value;
+								}
+							}
+						}
+						break;
+					}
+					
+					// Save the found value
+					if( $pass && !empty($value))
+					{
+						$query = 'INSERT INTO '.cms_db_prefix().'module_servicedesk_incident_attributes
+						(incident_id, attr_id, value)
+						VALUES (?,?,?)';
+						$dbr = $db->Execute( $query, array( $incident_id, $fldid, $value) );
+					}	
+				}
+			}
+
 			$params = array('tab_message'=> 'incidentupdated', 'active_tab' => 'incidents');
 			$this->Redirect($id, 'defaultadmin', $returnid, $params);
 		}
@@ -244,6 +322,91 @@ echo $this->StartTabContent();
 			$start_date = $row['start_date'];
 		}
 	}
+	if ($servicedeskversion == 'gold') {
+		// Retrieve attributes 
+		$query = 'SELECT * FROM '.cms_db_prefix().'module_servicedesk_attributes';
+		$attributedefs = $db->GetArray($query);
+		if( isset($params['incident_id']) ) {
+			// Connect any available values of the attributes
+			$query = 'SELECT * FROM '.cms_db_prefix().'module_servicedesk_incident_attributes
+				WHERE incident_id = ?';
+			$attributevals = $db->GetArray($query,array((int)$params['incident_id']));
+			if( $attributevals ) {
+				$tmp = sdattr_utils::MergeByKeys($attributedefs,$attributevals,'attr_id','attr_id');
+				$attributedefs = $tmp;
+			}
+		}
+		
+		$attributes = array();
+		foreach( $attributedefs as $oneattribute )
+		{
+			if( !isset($oneattribute['value']) ) $oneattribute['value'] = '';
+			
+			$oneattribute['hidden'] = $this->CreateInputHidden($id,'info_'.$oneattribute['name'],
+					 $oneattribute['type'].','.$oneattribute['attr_id']);
+		 
+			switch( $oneattribute['type'] ) {
+				case 'textbox':
+					$size = min(50,$oneattribute['max_length']);
+					$oneattribute['field'] = $this->CreateInputText($id,'fld_'.$oneattribute['name'],
+						$oneattribute['value'],$size,$oneattribute['max_length']);
+					break;
+				case 'textarea':
+					$oneattribute['field'] = $this->CreateTextArea(true,$id,$oneattribute['value'],'fld_'.
+						$oneattribute['name']);
+					break;
+				case 'checkbox':
+					$oneattribute['field'] = $this->CreateInputCheckbox($id,'fld_'.$oneattribute['name'],
+						1,$oneattribute['value']);
+					break;
+				case 'dropdown':
+					{
+						$tmp = explode("\n",$oneattribute['options']);
+						$tmp2 = array();
+						foreach( $tmp as $one )
+						{
+							$one = trim($one);
+							$tmp2[$one] = $one;
+						}
+						$oneattribute['field'] = $this->CreateInputDropdown($id,'fld_'.$oneattribute['name'],
+							$tmp2,-1,$oneattribute['value']);
+					}
+					break;
+				case 'image':
+					if( !empty($oneattribute['value']) ) {
+						$dest = cms_join_path('..','uploads',$this->GetName(),
+							'Incident_'.$incident_id,$oneattribute['value']);
+						$linktofile = '<a href="'.$dest.'" target="_blank">'.$oneattribute['value'].'</a>';
+						$oneattribute['display_value'] = $this->CreateInputHidden($id,'fld_'.$oneattribute['name'],
+							$oneattribute['value']).$linktofile;
+						$oneattribute['delete_attribute'] = $this->CreateInputCheckbox($id,'del_'.
+							$oneattribute['name'],1,0);
+					}
+					$oneattribute['field'] = $this->CreateInputHidden($id,'fld_'.$oneattribute['name'],
+						$oneattribute['value']).$this->CreateFileUploadInput($id,'fld_'.$oneattribute['name'],
+							'',30);
+					break;
+				case 'file':
+					if( !empty($oneattribute['value']) ) {
+						$dest = cms_join_path('..','uploads',$this->GetName(),
+							'Incident_'.$incident_id,$oneattribute['value']);
+						$linktofile = '<a href="'.$dest.'" target="_blank">'.$oneattribute['value'].'</a>';
+						$oneattribute['display_value'] = $this->CreateInputHidden($id,'fld_'.$oneattribute['name'],
+							$oneattribute['value']).$linktofile;
+						$oneattribute['delete_attribute'] = $this->CreateInputCheckbox($id,'del_'.$oneattribute['name'],1,0);
+					}
+					$oneattribute['field'] = $this->CreateInputHidden($id,'fld_'.$oneattribute['name'],
+							$oneattribute['value']).$this->CreateFileUploadInput($id,'fld_'.$oneattribute['name'],'',30);
+					break;
+			}
+			$attributes[] = $oneattribute;
+		}
+		if( count($attributes) ) {
+		  $smarty->assign('attributes',$attributes);
+		  $smarty->assign('countattributes', count($attributes));
+		
+		}
+	}
 	
 	// Prepare a list of categories
 	$categorylist = array();
@@ -270,7 +433,7 @@ echo $this->StartTabContent();
 	$priorityseqdropdown = $this->GetListPrioritySeq();
 	
 	#Display template
-	$smarty->assign('startform', $this->CreateFormStart($id, 'editincident', $returnid));
+	$smarty->assign('startform', $this->CreateFormStart($id, 'editincident', $returnid, 'post', 'multipart/form-data'));
 	$smarty->assign('endform', $this->CreateFormEnd());
 	$smarty->assign('descriptiontext', $this->Lang('incidentdescription'));
 	$smarty->assign('descriptioninput', $this->CreateInputText($id, 'description', $description, 80, 80, 'class="defaultfocus"'));
@@ -301,7 +464,8 @@ echo $this->StartTabContent();
 	$smarty->assign('sendmailinput', $this->CreateInputCheckbox($id, 'sendmail', true, $sendmail));
 	$smarty->assign('ownertext', $this->Lang('owner'));
 	$smarty->assign('ownerinput', $this->CreateInputDropdown($id, 'owner_id', $ownerlist, '', $usedowner_id));
-	
+	$smarty->assign('title_attributes', $this->Lang('title_attributes'));
+
 	$smarty->assign('hidden',
 		$this->CreateInputHidden($id, 'incident_id', $incident_id).
 		$this->CreateInputHidden($id, 'start_date', $start_date).
